import { Theme } from 'types';
export declare function applyTheme(theme?: Theme): {
    lineNumberContainerStyle: {
        fontSize: string;
        lineHeight: number;
        color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
            [key: string]: any;
        }> | {
            [key: string]: any;
        }> | {
            [key: string]: any;
        }> | {
            [key: string]: any;
        }> | {
            [key: string]: any;
        }> | {
            [key: string]: any;
        }> | {
            [key: string]: any;
        }> | {
            [key: string]: any;
        }> | {
            [key: string]: any;
        }> | {
            [key: string]: any;
        }> | {
            [key: string]: any;
        }> | {
            [key: string]: any;
        }> | ArrayLike<number> | undefined;
        backgroundColor: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
            [key: string]: any;
        }> | {
            [key: string]: any;
        }> | {
            [key: string]: any;
        }> | {
            [key: string]: any;
        }> | {
            [key: string]: any;
        }> | {
            [key: string]: any;
        }> | {
            [key: string]: any;
        }> | {
            [key: string]: any;
        }> | {
            [key: string]: any;
        }> | {
            [key: string]: any;
        }> | {
            [key: string]: any;
        }> | {
            [key: string]: any;
        }> | ArrayLike<number> | undefined;
        flexShrink: number;
        padding: number;
        textAlign: string;
        userSelect: string;
    };
    codeBlockStyle: {
        key: {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
            fontWeight: string;
        };
        keyword: {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
            fontWeight: string;
        };
        'attr-name': {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
        };
        selector: {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
        };
        comment: {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
            fontFamily: string;
            fontStyle: string;
        };
        'block-comment': {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
            fontFamily: string;
            fontStyle: string;
        };
        'function-name': {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
        };
        'class-name': {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
        };
        doctype: {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
        };
        substr: {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
        };
        namespace: {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
        };
        builtin: {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
        };
        entity: {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
        };
        bullet: {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
        };
        code: {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
        };
        addition: {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
        };
        regex: {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
        };
        symbol: {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
        };
        variable: {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
        };
        url: {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
        };
        'selector-attr': {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
        };
        'selector-pseudo': {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
        };
        type: {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
        };
        string: {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
        };
        quote: {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
        };
        tag: {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
        };
        deletion: {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
        };
        title: {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
        };
        section: {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
        };
        'meta-keyword': {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
        };
        meta: {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
        };
        italic: {
            fontStyle: string;
        };
        bold: {
            fontWeight: string;
        };
        function: {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
        };
        number: {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
        };
        'pre[class*="language-"]': {
            fontSize: string;
            fontFamily: string;
            background: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
            borderRadius: number;
            display: string;
            lineHeight: number;
            overflowX: string;
            whiteSpace: string;
        };
    };
    inlineCodeStyle: {
        key: {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
            fontWeight: string;
        };
        keyword: {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
            fontWeight: string;
        };
        'attr-name': {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
        };
        selector: {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
        };
        comment: {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
            fontFamily: string;
            fontStyle: string;
        };
        'block-comment': {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
            fontFamily: string;
            fontStyle: string;
        };
        'function-name': {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
        };
        'class-name': {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
        };
        doctype: {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
        };
        substr: {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
        };
        namespace: {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
        };
        builtin: {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
        };
        entity: {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
        };
        bullet: {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
        };
        code: {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
        };
        addition: {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
        };
        regex: {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
        };
        symbol: {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
        };
        variable: {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
        };
        url: {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
        };
        'selector-attr': {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
        };
        'selector-pseudo': {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
        };
        type: {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
        };
        string: {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
        };
        quote: {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
        };
        tag: {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
        };
        deletion: {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
        };
        title: {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
        };
        section: {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
        };
        'meta-keyword': {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
        };
        meta: {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
        };
        italic: {
            fontStyle: string;
        };
        bold: {
            fontWeight: string;
        };
        function: {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
        };
        number: {
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
        };
        'pre[class*="language-"]': {
            padding: string;
            display: string;
            whiteSpace: string;
            fontSize: string;
            fontFamily: string;
            background: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
            color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | {
                [key: string]: any;
            }> | ArrayLike<number> | undefined;
            borderRadius: number;
            lineHeight: number;
            overflowX: string;
        };
    };
    codeContainerStyle: {
        fontSize: string;
        fontFamily: string;
        lineHeight: number;
        padding: number;
    };
};
