declare const _default: {
    lineNumberColor: string;
    lineNumberBgColor: string;
    backgroundColor: string;
    textColor: string;
    substringColor: string;
    keywordColor: string;
    attributeColor: string;
    selectorAttributeColor: string;
    docTagColor: undefined;
    nameColor: string;
    builtInColor: string;
    literalColor: string;
    bulletColor: string;
    codeColor: string;
    additionColor: string;
    regexpColor: string;
    symbolColor: string;
    variableColor: string;
    templateVariableColor: string;
    linkColor: string;
    selectorClassColor: string;
    typeColor: string;
    stringColor: string;
    selectorIdColor: undefined;
    quoteColor: string;
    templateTagColor: string;
    deletionColor: string;
    titleColor: string;
    sectionColor: string;
    commentColor: string;
    metaKeywordColor: string;
    metaColor: string;
    functionColor: string;
    numberColor: string;
};
export default _default;
