/// <reference types="react" />
import CodeBlock from './components/CodeBlock';
declare const _default: import("react").ForwardRefExoticComponent<Pick<import("styled-components").ExecutionProps, "as" | "forwardedAs"> & {
    theme?: import("styled-components").DefaultTheme | undefined;
} & {
    text?: string | undefined;
    codeTagProps?: {} | undefined;
    language?: string | undefined;
    customStyle?: Record<string, string> | undefined;
    lineNumberContainerStyle?: {} | undefined;
    showLineNumbers?: boolean | undefined;
    startingLineNumber?: number | undefined;
    wrapLongLines?: boolean | undefined;
    highlight?: string | undefined;
    codeBlockStyle?: {} | undefined;
    codeContainerStyle?: {} | undefined;
} & import("react").RefAttributes<typeof CodeBlock>> & {};
export default _default;
