import { CodeBlockTheme } from '../../types';
export declare const getStyles: (theme: CodeBlockTheme) => {
    color: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
        [key: string]: any;
    }> | {
        [key: string]: any;
    }> | {
        [key: string]: any;
    }> | {
        [key: string]: any;
    }> | {
        [key: string]: any;
    }> | {
        [key: string]: any;
    }> | {
        [key: string]: any;
    }> | {
        [key: string]: any;
    }> | {
        [key: string]: any;
    }> | {
        [key: string]: any;
    }> | {
        [key: string]: any;
    }> | {
        [key: string]: any;
    }> | ArrayLike<number> | undefined;
    border: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
        [key: string]: any;
    }> | {
        [key: string]: any;
    }> | {
        [key: string]: any;
    }> | {
        [key: string]: any;
    }> | {
        [key: string]: any;
    }> | {
        [key: string]: any;
    }> | {
        [key: string]: any;
    }> | {
        [key: string]: any;
    }> | {
        [key: string]: any;
    }> | {
        [key: string]: any;
    }> | {
        [key: string]: any;
    }> | {
        [key: string]: any;
    }> | ArrayLike<number> | undefined;
    bgColor: string | number | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | import("color")<string | number | ArrayLike<number> | any | {
        [key: string]: any;
    }> | {
        [key: string]: any;
    }> | {
        [key: string]: any;
    }> | {
        [key: string]: any;
    }> | {
        [key: string]: any;
    }> | {
        [key: string]: any;
    }> | {
        [key: string]: any;
    }> | {
        [key: string]: any;
    }> | {
        [key: string]: any;
    }> | {
        [key: string]: any;
    }> | {
        [key: string]: any;
    }> | {
        [key: string]: any;
    }> | ArrayLike<number> | undefined;
};
