export declare const SUPPORTED_LANGUAGE_ALIASES: readonly {
    name: string;
    alias: string[];
    value: string;
}[];
export declare const normalizeLanguage: (language?: string | undefined) => string;
